Module report

Module report 

Report types for evaluation results.

This module defines the data structures for evaluation reports that can be serialized to JSON or CSV.

Structs

CodecResult
Result from evaluating a single codec on a single image at a single quality.
CorpusReport
Report for a corpus of images.
ImageReport
Report for a single image evaluated across multiple codecs and quality levels.