pub struct ParetoFront {
pub points: Vec<RDPoint>,
}Expand description
Pareto front of rate-distortion points.
Fields
points: Vec<RDPoint>Points on the Pareto front (non-dominated).
Implementations
Sourceimpl ParetoFront
impl ParetoFront
Sourcepub fn compute(points: &[RDPoint]) -> Self
pub fn compute(points: &[RDPoint]) -> Self
Compute the Pareto front from a set of points.
Returns a new ParetoFront containing only the non-dominated points.
Sourcepub fn at_quality(&self, min_quality: f64) -> Vec<&RDPoint>
pub fn at_quality(&self, min_quality: f64) -> Vec<&RDPoint>
Get points that achieve at least the target quality.
Sourcepub fn at_bpp(&self, max_bpp: f64) -> Vec<&RDPoint>
pub fn at_bpp(&self, max_bpp: f64) -> Vec<&RDPoint>
Get points that achieve at most the target bpp.
Sourcepub fn best_at_bpp(&self, max_bpp: f64) -> Option<&RDPoint>
pub fn best_at_bpp(&self, max_bpp: f64) -> Option<&RDPoint>
Get the best point (highest quality) at or below the target bpp.
Sourcepub fn best_at_quality(&self, min_quality: f64) -> Option<&RDPoint>
pub fn best_at_quality(&self, min_quality: f64) -> Option<&RDPoint>
Get the most efficient point (lowest bpp) at or above the target quality.
Sourcepub fn filter_codec(&self, codec: &str) -> Vec<&RDPoint>
pub fn filter_codec(&self, codec: &str) -> Vec<&RDPoint>
Filter to points from a specific codec.